"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.validateStructureOfYamlFiles = void 0;
const yaml_schema_1 = require("@fern-api/yaml-schema");
const Result_1 = require("./types/Result");
function validateStructureOfYamlFiles(files) {
    const validatedFiles = {};
    const failures = {};
    for (const [relativeFilePath, parsedFileContents] of Object.entries(files)) {
        const parsed = yaml_schema_1.FernConfigurationSchema.safeParse(parsedFileContents);
        if (parsed.success) {
            validatedFiles[relativeFilePath] = parsed.data;
        }
        else {
            failures[relativeFilePath] = {
                type: Result_1.WorkspaceParserFailureType.STRUCTURE_VALIDATION,
                error: parsed.error,
            };
        }
    }
    if (Object.keys(failures).length > 0) {
        return {
            didSucceed: false,
            failures,
        };
    }
    else {
        return {
            didSucceed: true,
            validatedFiles,
        };
    }
}
exports.validateStructureOfYamlFiles = validateStructureOfYamlFiles;
